@@ -375,13 +375,20 @@ static void get_task_details(struct app_flow *flow)
 	if (NULL == curr)
 		return;
 
+	get_process_creation_time(curr, &flow->process_create_time);
+
 	flow->file_path_len =
 		get_exepath_from_task(curr, flow->file_path, ARRAY_SIZE(flow->file_path));
 
 	process_name = file_name_from_path(flow->file_path);
 
 	if (process_name && strcmp(process_name, default_name)) {
+
+#if (KERNEL_VERSION(6, 5, 0) <= LINUX_VERSION_CODE)
+		strscpy(flow->file_name, process_name, sizeof(flow->file_name));
+#else
 		strlcpy(flow->file_name, process_name, sizeof(flow->file_name));
+#endif
 		flow->file_name_len = strlen(flow->file_name);
 	}
 	else {
@@ -401,7 +408,12 @@ static void get_task_details(struct app_flow *flow)
 	parent_process_name = file_name_from_path(flow->parent_file_path);
 
 	if (parent_process_name && strcmp(parent_process_name, default_name)) {
+
+#if (KERNEL_VERSION(6, 5, 0) <= LINUX_VERSION_CODE)
+		strscpy(flow->parent_file_name, parent_process_name, sizeof(flow->parent_file_name));
+#else
 		strlcpy(flow->parent_file_name, parent_process_name, sizeof(flow->parent_file_name));
+#endif
 		flow->parent_file_name_len = strlen(flow->parent_file_name);
 	}
 	else {
